@@ -5,13 +5,14 @@ BACKEND_ALIASES = {
     "database": "ghettoq.backends.database.DatabaseBackend",
     "mongodb": "ghettoq.backends.mongodb.MongodbBackend",
     "beanstalk": "ghettoq.backends.beanstalk.BeanstalkBackend",
+    "couchdb": "ghettoq.backends.couch_db.CouchdbBackend",
 }
 _backend_cache = {}
 
 
 def resolve_backend(backend):
     backend = BACKEND_ALIASES.get(backend.lower(), backend)
-    backend_module_name, _, backend_cls_name = backend.rpartition(".")
+    backend_module_name, backend_cls_name = backend.rsplit('.', 1)
     return backend_module_name, backend_cls_name
 
 
